# dbt-dameng

[![dbt-dameng docs](https://img.shields.io/badge/docs-read-blue)](https://docs.getdbt.com/reference/warehouse-setups/dameng-setup)
[![dbt-dameng license](https://img.shields.io/badge/license-Apache%202.0-blue)][4]

`dbt-dameng` implements [dbt (building-a-new-adapter)](https://docs.getdbt.com/guides/dbt-ecosystem/adapter-development/3-building-a-new-adapter) functionalities for the Dameng database. 

> dbt-dameng was created and maintained by on [GitHub repo](https://github.com/sqlking22/dbt-dameng)



## Installation

```bash
pip install dbt-dameng
```


## Documentation

Please refer to the [Dameng setup on dbt docs website][1] for documentation.

## Sample project

To get started, a sample dbt project can be found in the directory [/dbt_adbs_test_project][5].

## Contributing

This project welcomes contributions from the community. Before submitting a pull request, please [review our contribution guide](./CONTRIBUTING.md).

## Security

Please consult the [security guide](./SECURITY.md) for our responsible security vulnerability disclosure process.

## License
dbt-dameng is licensed under Apache 2.0 License which you can find [here][4].

[1]: https://docs.getdbt.com/reference/warehouse-profiles/dameng-profile
[2]: https://github.com/dameng/dbt-dameng/blob/main/CONTRIBUTING.md
[3]: https://github.com/dameng/dbt-dameng/blob/main/SECURITY.md
[4]: https://github.com/dameng/dbt-dameng/blob/main/LICENSE.txt
[5]: https://github.com/dameng/dbt-dameng/tree/main/dbt_adbs_test_project
